@@ -1,27 +1,27 @@
-# Limit initial values to allowed range
-mtc.init.limit <- function(model, value, offset=rep(0.0, model[['n.chain']])) {
-  limits <- ll.call("scale.limit.inits", model)
-  too.small <- (value + offset) < limits[1]
-  too.large <- (value + offset) > limits[2]
-  value[too.small] <- limits[1] - offset[too.small]
-  value[too.large] <- limits[2] - offset[too.large]
-  value
+# Find upper and lower bounds for the baseline value given the delta values
+mtc.init.baseline.limit <- function(model, delta) {
+  limits <- ll.call("inits.info", model)[['limits']]
+  c(max(limits[1] - c(0, delta), na.rm=TRUE),
+    min(limits[2] - c(0, delta), na.rm=TRUE))
 }
 
 # Initial values for study-level absolute treatment effects based on (adjusted) MLE
-mtc.init.baseline.effect <- function(model, study, treatment) {
+mtc.init.baseline.effect <- function(model, study, treatment, delta) {
   data.ab <- model[['network']][['data.ab']]
   data <- data.ab[data.ab[['study']] == study & data.ab[['treatment']] == treatment, , drop=TRUE]
   data <- unlist(data[ll.call("required.columns.ab", model)])
   mle <- ll.call("mtc.arm.mle", model, data)
-  mtc.init.limit(
-    model,
-    rnorm(model[['n.chain']], mle['mean'], model[['var.scale']] * mle['sd'])
-  )
+
+  limits <- sapply(1:model[['n.chain']], function(i) {
+    mtc.init.baseline.limit(
+      model, delta[i, ]
+    )
+  })
+  truncnorm::rtruncnorm(n=model[['n.chain']], mean=mle['mean'], sd=model[['var.scale']] * mle['sd'], a=limits[1,], b=limits[2,])
 }
 
 # Initial values for study-level relative effects based on (adjusted) MLE
-mtc.init.relative.effect <- function(model, study, t1, t2, mu=rep(0.0, model[['n.chain']])) {
+mtc.init.relative.effect <- function(model, study, t1, t2) {
   data <- model[['network']][['data.ab']]
   if (!is.null(data) && study %in% data[['study']]) {
     columns <- ll.call("required.columns.ab", model)
@@ -32,11 +32,7 @@ mtc.init.relative.effect <- function(model, study, t1, t2, mu=rep(0.0, model[['n
     data <- data[data[['study']] == study & data[['treatment']] == t2, , drop=TRUE]
     mle <- c('mean'=data[['diff']], 'sd'=data[['std.err']])
   }
-  mtc.init.limit(
-    model,
-    rnorm(model[['n.chain']], mle['mean'], model[['var.scale']] * mle['sd']),
-    mu
-  )
+  rnorm(model[['n.chain']], mle['mean'], model[['var.scale']] * mle['sd'])
 }
 
 # Initial values for pooled effect (basic parameter) based on
@@ -63,7 +59,6 @@ mtc.init.pooled.effect <- function(model, t1, t2, om.scale) {
     study.mle
   }
 
-
   study.mle <- NULL
   data.ab <- model[['network']][['data.ab']]
   if (!is.null(data.ab)) {
@@ -106,45 +101,83 @@ mtc.init <- function(model) {
   data.ab <- model[['network']][['data.ab']]
   data.re <- model[['network']][['data.re']]
   s.mat <- arm.index.matrix(model[['network']])
-  studies <- rle(as.character(data.ab[['study']]))[['values']]
 
-  # Generate initial values for each parameter
-  mu <- sapply(studies, function(study) {
-    mtc.init.baseline.effect(model, study, data.ab[['treatment']][s.mat[study, 1, drop=TRUE]])
-  })
-  if (!is.matrix(mu)) {
-    mu <- matrix(mu, nrow=model[['n.chain']], ncol=length(studies))
-  }
-  studies <- c(studies, rle(as.character(data.re[['study']]))[['values']])
-  ts <- c(as.character(data.ab[['treatment']]), as.character(data.re[['treatment']]))
-  delta <- lapply(studies, function(study) {
-    sapply(1:ncol(s.mat), function(i) {
-      if (i == 1 || is.na(s.mat[study, i, drop=TRUE])) rep(NA, model[['n.chain']])
-      else mtc.init.relative.effect(
-           model, study,
-           ts[s.mat[study, 1, drop=TRUE]],
-           ts[s.mat[study, i, drop=TRUE]],
-           if (study %in% colnames(mu)) { mu[, study, drop=TRUE] } else { rep(0.0, model[['n.chain']]) })
-    })
-  })
+  # initial values for the relative effects and heterogeneity
   graph <- if(!is.null(model[['tree']])) model[['tree']] else model[['graph']]
   if (!is.null(graph)) {
     params <- mtc.basic.parameters(model)
     d <- sapply(E(graph), function(e) {
-      v <- get.edge(graph, e)
+      v <- ends(graph, e, names=FALSE)
       mtc.init.pooled.effect(model, V(graph)[v[1]]$name, V(graph)[v[2]]$name, model[['om.scale']])
     })
-    hy <- mtc.init.hy(model[['hy.prior']], model[['om.scale']], model[['n.chain']])
   } else {
     params <- c()
-    hy <- c()
+  }
+
+  hy <- if (model[['linearModel']] == 'random') {
+    mtc.init.hy(model[['hy.prior']], model[['om.scale']], model[['n.chain']])
+  } else {
+    c()
+  }
+
+  studies.ab <- rle(as.character(data.ab[['study']]))[['values']]
+  studies.re <- rle(as.character(data.re[['study']]))[['values']]
+  studies <- c(studies.ab, studies.re)
+
+  # initial values for the random effects
+  # the fixed effect models don't need initial values for the random effects,
+  # but the values must be computed from the basic parameters to be able to
+  # restrict the initial values for the baseline effect correctly.
+  ts <- c(as.character(data.ab[['treatment']]), as.character(data.re[['treatment']]))
+  delta <- if (model[['linearModel']] == 'random') {
+    lapply(studies, function(study) {
+      sapply(1:ncol(s.mat), function(i) {
+        if (i == 1 || is.na(s.mat[study, i, drop=TRUE])) rep(NA, model[['n.chain']])
+        else
+          mtc.init.relative.effect(
+            model, study,
+            ts[s.mat[study, 1, drop=TRUE]],
+            ts[s.mat[study, i, drop=TRUE]])
+      })
+    })
+  } else if (model[['linearModel']] == 'fixed' && !is.null(graph)) {
+    comparisons <- mtc.comparisons.baseline(model[['network']])
+    effects <- d %*% mtc.model.call('func.param.matrix', model, t1=comparisons[['t1']], t2=comparisons[['t2']])
+    lapply(studies, function(study) {
+      sapply(1:ncol(s.mat), function(i) {
+        if (i == 1 || is.na(s.mat[study, i, drop=TRUE])) rep(NA, model[['n.chain']])
+        else {
+          t1 <- ts[s.mat[study, 1, drop=TRUE]]
+          t2 <- ts[s.mat[study, i, drop=TRUE]]
+          if (is.na(t2)) {
+            rep(NA, model[['n.chain']])
+          } else {
+            effects[, paste('d', t1, t2, sep='.'), drop=TRUE]
+          }
+        }
+      })
+    })
+  } else {
+    c()
+  }
+
+  # Generate initial values for the baseline effect
+  # These must be restricted so as not to generate invalid values for the likelihood
+  mu <- sapply(studies.ab, function(study) {
+    mtc.init.baseline.effect(model, study, data.ab[['treatment']][s.mat[study, 1, drop=TRUE]], delta[[which(studies==study)]])
+  })
+  if (!is.matrix(mu)) {
+    mu <- matrix(mu, nrow=model[['n.chain']], ncol=length(studies))
   }
 
   # Separate the initial values per chain
   lapply(1:model[['n.chain']], function(chain) {
     c(
       if (!is.null(data.ab)) {
-        list(mu = mu[chain, , drop=TRUE])
+        info <- ll.call('inits.info', model)
+        rval <- list()
+        rval[[info[['param']]]] <- info[['transform']](mu[chain, , drop=TRUE])
+        rval
       } else {
         list()
       },
