@@ -5,8 +5,10 @@ ll.call <- function(fnName, model, ...) {
 
 ll.defined <- function(model) {
   fns <- c('mtc.arm.mle', 'mtc.rel.mle', 'mtc.code.likelihood',
-    'scale.log', 'scale.name', 'scale.limit.inits',
-    'required.columns.ab')
+    'fitted.values.parameter', 'deviance',
+    'scale.log', 'scale.name', 'inits.info',
+    'required.columns.ab', 'validate.data',
+    'study.baseline.priors')
   fns <- paste(fns, model[['likelihood']], model[['link']], sep=".")
-  all(exists(fns, mode='function'))
+  all(sapply(fns, function(fn) { exists(fn, mode='function') }))
 }
