@@ -1,7 +1,6 @@
 context("[validate] Thrombolytic drugs data from Lu & Ades, J Am Stat Assoc 2006;101(474):447-459, Table 3")
 
 test_that("The summaries match", {
-  network <- read.mtc.network(system.file('extdata/luades-thrombolytic.gemtc', package='gemtc'))
-  result <- replicate.example("luades-thrombolytic", network)
+  result <- replicate.example("luades-thrombolytic", thrombolytic)
   compare.summaries(result$s1, result$s2)
 })
